@@ -1,5 +1,5 @@
 <?php
-/* $Id: belarusian_latin-utf-8.inc.php 10445 2007-06-16 12:35:08Z lem9 $ */
+/* $Id: belarusian_latin-utf-8.inc.php 10468 2007-06-27 21:01:13Z lem9 $ */
 
 /**
 * Translated by:
@@ -178,8 +178,6 @@ $strCreationDates = 'Stvareńnie/Abnaŭleńnie/Pravierka dat';
 $strCriteria = 'Kryter';
 $strCroatian = 'Charvackaja';
 $strCSV = 'CSV';
-$strCSVImportOptions = 'Opcyi CSV';
-$strCSVOptions = 'Opcyi CSV';
 $strCyrillic = 'Kiryličnaja';
 $strCzech = 'Českaja';
 $strCzechSlovak = 'Čechasłavackaja';
@@ -262,7 +260,6 @@ $strEscapeWildcards = 'Symbali padstanoŭki _ i % musiać być ekranavanymi symb
 $strEsperanto = 'Esperanta';
 $strEstonian = 'Estonskaja';
 $strExcelEdition = 'Versija Excel';
-$strExcelOptions = 'Opcyi Excel';
 $strExecuteBookmarked = 'Vykanać zapyt z zakładak';
 $strExplain = 'Tłumačyć SQL';
 $strExport = 'Ekspart';
@@ -273,7 +270,6 @@ $strExtra = 'Dadatkova';
 $strFailedAttempts = 'Niaŭdałych sprobaŭ';
 $strFieldHasBeenDropped = 'Pole %s było vydalenaje';
 $strField = 'Pole';
-$strFieldsEmpty = ' Nia ŭviedzienaja kolkaść paloŭ! ';
 $strFieldsEnclosedBy = 'Pali ŭziatyja ŭ';
 $strFieldsEscapedBy = 'Pali ekranujucca';
 $strFields = 'Pali';
@@ -320,15 +316,12 @@ $strHasBeenAltered = 'była źmienienaja.';
 $strHasBeenCreated = 'była stvoranaja.';
 $strHaveToShow = 'Vam nieabchodna vybrać prynamsi adnu kalonku dla adlustravańnia';
 $strHebrew = 'Habrejskaja';
-$strHexForBinary = 'Vykarystoŭvać šasnaccatkavyja liki dla dvojkavych paloŭ';
 $strHome = 'Da pačatku';
 $strHomepageOfficial = 'Aficyjnaja staronka phpMyAdmin';
 $strHost = 'Chost';
 $strHostEmpty = 'Pustoje imia chostu!';
 $strHTMLExcel = 'Microsoft Excel 2000';
-$strHTMLExcelOptions = 'Opcyi Microsoft Excel 2000';
 $strHTMLWord = 'Microsoft Word 2000';
-$strHTMLWordOptions = 'Opcyi Microsoft Word 2000';
 $strHungarian = 'Vuhorskaja';
 
 $strIcelandic = 'Iślandzkaja';
@@ -346,10 +339,7 @@ $strIndexHasBeenDropped = 'Indeks %s byŭ vydaleny';
 $strIndex = 'Indeks';
 $strIndexName = 'Imia indeksa:';
 $strIndexType = 'Typ indeksa:';
-$strIndexWarningMultiple = 'Bolš za adzin %s kluč byŭ stvorany dla kalonki `%s`';
-$strIndexWarningPrimary = 'Abodva klučy PRIMARY i INDEX pavinny być vyznačany dla kalonki `%s`';
 $strIndexWarningTable = 'Prablemy z indeksami dla tablicy `%s`';
-$strIndexWarningUnique = 'Abodva klučy UNIQUE i INDEX pavinny być vyznačany dla kalonki `%s`';
 $strInnoDBAutoextendIncrement = 'Aŭtapašyralnaje pryraščeńnie';
 $strInnoDBAutoextendIncrementDesc = ' Pamier pryraščeńnia dla pašyreńnia pamieru prastory aŭtapašyralnaj tablicy, kali jana zapoŭnicca.';
 $strInnoDBBufferPoolSizeDesc = 'Pamier buferu ŭ pamiaci, jaki InnoDB vykarystoŭvaje dla kešavańnia dadzienych i indeksaŭ tablic.';
@@ -405,11 +395,9 @@ $strLatexContinued = '(praciah)';
 $strLatexIncludeCaption = 'Uklučyć zahałovak tablicy';
 $strLatexLabel = 'Kluč mietki';
 $strLaTeX = 'LaTeX';
-$strLaTeXOptions = 'Opcyi LaTeX';
 $strLatexStructure = 'Struktura tablicy __TABLE__';
 $strLatvian = 'Łatvijskaja';
 $strLDI = 'CSV z vykarystańniem LOAD DATA';
-$strLDIImportOptions = 'Opcyi CSV-impartavańnia, vykarystoŭvajučy LOAD DATA';
 $strLDILocal = 'Vykarystoŭvać klučavoje słova LOCAL';
 $strLengthSet = 'Daŭžynia/Značeńni*';
 $strLimitNumRows = 'Kolkaść radkoŭ na staronku';
@@ -509,9 +497,7 @@ $strNumSearchResultsTotal = '<b>Ahułam:</b> <i>%s</i> supadzieńniaŭ';
 $strNumTables = 'Tablic';
 
 $strOK = 'OK';
-$strOpenDocumentSpreadsheetOptions = 'Opcyi specyfikacyi Open Document';
 $strOpenDocumentSpreadsheet = 'Specyfikacyja Open Document';
-$strOpenDocumentTextOptions = 'Opcyi tekstu Open Document';
 $strOpenDocumentText = 'Tekst Open Document';
 $strOpenNewWindow = 'Adkryć novaje akno phpMyAdmin';
 $strOperations = 'Aperacyi';
@@ -534,7 +520,6 @@ $strPassword = 'Parol';
 $strPdfDbSchema = 'Struktura bazy "%s" — staronka %s';
 $strPdfInvalidTblName = 'Tablicy "%s" nie isnuje!';
 $strPdfNoTables = 'Niama tablic';
-$strPDFOptions = 'Parametry PDF';
 $strPDF = 'PDF';
 $strPDFReportExplanation = '(Gieneruje spravazdaču z dadzienymi asobnaj tablicy)';
 $strPDFReportTitle = 'Zahałovak spravazdačy';
@@ -831,8 +816,6 @@ $strSpanish = 'Hišpanskaja';
 $strSplitWordsWithSpace = 'Słovy padzielenyja prahałam (" ").';
 $strSQLCompatibility = 'Režym sumiaščalnaści SQL';
 $strSQLExportType = 'Typ ekspartu';
-$strSQLImportOptions = 'Parametry SQL';
-$strSQLOptions = 'Opcyi SQL';
 $strSQLParserBugMessage = 'Mahčyma, vy znajšli pamyłku ŭ SQL-parsery. Kali łaska, uvažliva praviercie vyš zapyt i adpaviednaść dvukośsiaŭ u im. Inšaj mahčymaj pryčynaj pamyłki moža być toje, što vy zahruzili fajł z dvojkavymi dadzienymi pa-za miežami tekstu, vyłučanaha dvukośsiami. Vy taksama možacie pasprabavać adpravić vaš zapyt z kamandnaha radka MySQL. Paviedamleńnie pra pamyłku servera MySQL pryviedzienaje nižej, moža taksama dapamahčy vam vyśvietlić pryčynu prablemu. Kali vy ŭsio jašče majecie prablemy abo parser paviedamlaje pra pamyłku, a z kamandnaha radku zapyt vykonvajecca, kali łaska, skaracicie vaš uviedzieny SQL-zapyt da adnaho zapytu, jaki vyklikaje pamyłku, i adpraŭcie paviedamleńnie pra pamyłku z blokam dadzienych, padadzienych u sekyci CUT nižej:';
 $strSQLParserUserError = 'Zdajecca, vaš SQL-zapyt utrymlivaje pamyłku. Paviedamleńnie pra pamyłku servera MySQL pryviedzienaje nižej, mahčyma, taksama dapamoža vam vyśvietlić pryčynu pamyłki';
 $strSQLQuery = 'SQL-zapyt';
@@ -852,7 +835,6 @@ $strStorageEngines = 'Mašyny zachavańnia dadzienych';
 $strStrucCSV = 'CSV';
 $strStrucData = 'Strukturu i dadzienyja';
 $strStrucExcelCSV = 'CSV dla dadzienych MS Excel';
-$strStrucNativeExcelOptions = 'Standartnyja opcyi ekspartavańnia ŭ Excel';
 $strStrucNativeExcel = 'Rodny farmat MS Excel';
 $strStrucOnly = 'Tolki strukturu';
 $strStructPropose = 'Prapanavanaja struktura tablicy';
@@ -969,7 +951,6 @@ $strWithChecked = 'Z adznačanymi:';
 $strWriteRequests = 'Zapytaŭ zapisu';
 $strWrongUser = 'Niapravilny łahin/parol. U dostupie admoŭlena.';
 
-$strXMLOptions = 'Opcyi XML';
 $strXML = 'XML';
 
 $strYes = 'Tak';
@@ -980,7 +961,6 @@ $strZip = 'archivavany ŭ zip';
 $strPmaWiki = 'phpMyAdmin wiki';  //to translate
 $strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
 $strDocSQL = 'DocSQL';  //to translate
-$strDocSQLOptions = 'DocSQL options';  //to translate
 $strTableName = 'Table name';  //to translate
 $strTableIsEmpty = 'Table seems to be empty!';  //to translate
 $strDbIsEmpty = 'Database seems to be empty!';  //to translate
@@ -1025,5 +1005,26 @@ $strErrorRelationExists = 'Error: relation already exists.';  //to translate
 $strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
 $strSnapToGrid = 'Snap to grid';  //to translate
 $strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
+$strUploadErrorIniSize = 'The uploaded file exceeds the upload_max_filesize directive in php.ini.';  //to translate
+$strUploadErrorFormSize = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';  //to translate
+$strUploadErrorPartial = 'The uploaded file was only partially uploaded.';  //to translate
+$strUploadErrorNoTempDir = 'Missing a temporary folder.';  //to translate
+$strUploadErrorCantWrite = 'Failed to write file to disk.';  //to translate
+$strUploadErrorExtension = 'File upload stopped by extension.';  //to translate
+$strUploadErrorUnknown = 'Unknown error in file upload.';  //to translate
 $strSessionStartupErrorGeneral = 'Cannot start session without errors, please check errors given in your PHP and/or webserver log file and configure your PHP installation properly.';  //to translate
+$strFieldInsertFromFileTempDirNotExists = 'Error moving the uploaded file, see FAQ 1.11';  //to translate
+$strViewName = 'VIEW name';  //to translate
+$strOptions = 'Options';  //to translate
+$strFiles = 'Files';  //to translate
+$strIndexesSeemEqual = 'The following indexes appear to be equal and one of them should be removed:';  //to translate
+$strMysqlLibDiffersServerVersion = 'Your PHP MySQL library version %s differs from your MySQL server version %s. This may cause unpredictable behavior.';  //to translate
+$strRoutines = 'Routines';  //to translate
+$strRoutineReturnType = 'Return type';  //to translate
+$strControluserFailed = 'Connection for controluser as defined in your configuration failed.';  //to translate
+$strHexForBLOB = 'Use hexadecimal for BLOB';  //to translate
+$strRestartInsertion = 'Restart insertion with %s rows';  //to translate
+$strTriggers = 'Triggers';  //to translate
+$strEvent = 'Event';  //to translate
+$strProfiling = 'Profiling';  //to translate
 ?>
