@@ -1,5 +1,5 @@
 <?php
-/* $Id: greek-utf-8.inc.php 10439 2007-06-15 17:13:29Z lem9 $ */
+/* $Id: greek-utf-8.inc.php 10468 2007-06-27 21:01:13Z lem9 $ */
 
 /* Translated by Kyriakos Xagoraris <theremon at users.sourceforge.net> */
 
@@ -123,7 +123,6 @@ $strCreatePdfFeat = 'Δημιουργία αρχείων PDF';
 $strCreate = 'Δημιουργία';
 $strCriteria = 'Κριτήρια';
 $strCroatian = 'Κροατικά';  
-$strCSVOptions = 'Επιλογές CSV';
 $strCyrillic = 'Κυριλλικά';  
 $strCzech = 'Τσεχικά';  
 
@@ -183,7 +182,6 @@ $strEnglishPrivileges = ' Σημείωση: Τα ονόματα προνομίω
 $strEnglish = 'Αγγλικά';  
 $strError = 'λάθος';
 $strEstonian = 'Εσθονικά';  
-$strExcelOptions = 'Επιλογές Excel';  
 $strExecuteBookmarked = 'Εκτέλεση αποθηκευμένου επερωτήματος';  
 $strExplain = 'Ανάλυση SQL';  
 $strExport = 'Εξαγωγή';  
@@ -192,7 +190,6 @@ $strExtra = 'Πρόσθετα';
 
 $strFailedAttempts = 'Αποτυχημένες προσπάθειες'; 
 $strFieldHasBeenDropped = 'Το πεδίο %s διεγράφη';
-$strFieldsEmpty = ' Η απαρίθμηση των πεδίων είναι κενή! ';
 $strFieldsEnclosedBy = 'Πεδία που περικλείονται σε';
 $strFieldsEscapedBy = 'Τα πεδία χρησιμοποιούν το χαρακτήρα διαφυγής ';
 $strFieldsTerminatedBy = 'Πεδία που τελειώνουν σε';
@@ -261,7 +258,6 @@ $strKorean = 'Κορεατικά';
 
 $strLandscape = 'Οριζόντια διάταξη';  
 $strLaTeX = 'LaTeX';  
-$strLaTeXOptions = 'Επιλογές LaTeX';  
 $strLengthSet = 'Μήκος/Τιμές*';
 $strLimitNumRows = 'Εγγραφές ανά σελίδα';
 $strLinesTerminatedBy = 'Γραμμές που τελειώνουν σε';
@@ -494,7 +490,6 @@ $strSize = 'Μέγεθος';
 $strSort = 'Ταξινόμηση';
 $strSpaceUsage = 'Χρήση χώρου';
 $strSplitWordsWithSpace = 'Οι λέξεις χωρίζονται από τον χαρακτήρα διαστήματος (" ").';
-$strSQLOptions = 'Επιλογές SQL';
 $strSQLParserBugMessage = 'Υπάρχει περίπτωση να εντοπίσατε ένα πρόβλημα στον SQL parser. Παρακαλώ εξετάστε το επερώτημά σας προσεκτικά και ελέγξτε ότι όλα τα εισαγωγικά ανοίγουν και κλείνουν σωστά. \'Αλλες πιθανές αιτίες μπορούν να είναι η αποστολή αρχείου με δυαδικό κώδικα εκτός εισαγωγικών. Μπορείτε επίσης να δοκιμάσετε το επερώτημά σας στη γραμμή εντολών της MySQL.  Εάν συνεχίζετε να έχετε πρόβλημα, ή εάν ο parser αποτυγχάνει όπου η γραμμή εντολών επιτυγχάνει, παρακαλώ απομονώστε το επερώτημα εκείνο που δημιουργεί το πρόβλημα και στείλτε αναφορά λάθους με τα δεδομένα που βρίσκονται στο τμήμα CUT που ακολουθεί:';  
 $strSQLParserUserError = 'Φαίνεται να υπάρχει ένα λάθος στο επερώτημά σας. Το κάτωθι λάθος διακομιστή MySQL, εάν υπάρχει κάποιο, μπορεί επίσης να σας βοηθήσει να διαγνώσετε το πρόβλημα.';
 $strSQLQuery = 'Εντολή SQL';
@@ -654,7 +649,6 @@ $strCopyDatabaseOK = 'Database %s has been copied to %s';  //to translate
 $strCreateDatabaseBeforeCopying = 'CREATE DATABASE before copying';  //to translate
 $strCreationDates = 'Creation/Update/Check dates';  //to translate
 $strCSV = 'CSV';  //to translate
-$strCSVImportOptions = 'CSV options';  //to translate
 $strCzechSlovak = 'Czech-Slovak';  //to translate
 
 $strDatabaseEmpty = 'The database name is empty!';  //to translate
@@ -693,11 +687,8 @@ $strGeneratePassword = 'Generate Password';  //to translate
 $strGeorgian = 'Georgian';  //to translate
 
 $strHandler = 'Handler';  //to translate
-$strHexForBinary = 'Use hexadecimal for binary fields';  //to translate
 $strHTMLExcel = 'Microsoft Excel 2000';  //to translate
-$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
 $strHTMLWord = 'Microsoft Word 2000';  //to translate
-$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate
 
 $strIcelandic = 'Icelandic';  //to translate
 $strIgnoreDuplicates = 'Ignore duplicate rows';  //to translate
@@ -705,10 +696,7 @@ $strIgnoreInserts = 'Use ignore inserts';  //to translate
 $strImportFormat = 'Format of imported file';  //to translate
 $strImport = 'Import';  //to translate
 $strImportSuccessfullyFinished = 'Import has been successfully finished, %d queries executed.';  //to translate
-$strIndexWarningMultiple = 'More than one %s key was created for column `%s`';//to translate
-$strIndexWarningPrimary = 'PRIMARY and INDEX keys should not both be set for column `%s`';//to translate
 $strIndexWarningTable = 'Problems with indexes of table `%s`';//to translate
-$strIndexWarningUnique = 'UNIQUE and INDEX keys should not both be set for column `%s`';//to translate
 $strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
 $strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
 $strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
@@ -747,7 +735,6 @@ $strLatexLabel = 'Label key';//to translate
 $strLatexStructure = 'Structure of table __TABLE__';//to translate
 $strLatvian = 'Latvian';  //to translate
 $strLDI = 'CSV using LOAD DATA';  //to translate
-$strLDIImportOptions = 'Options for CSV import using LOAD DATA';  //to translate
 $strLDILocal = 'Use LOCAL keyword';  //to translate
 $strLogServer = 'Server';  //to translate
 $strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate
@@ -786,7 +773,6 @@ $strOperator = 'Operator';  //to translate
 $strPagesToBeFlushed = 'Pages to be flushed';  //to translate
 $strPartialImport = 'Partial import';  //to translate
 $strPasswordHashing = 'Password Hashing';  //to translate
-$strPDFOptions = 'PDF options';  //to translate
 $strPDF = 'PDF';  //to translate
 $strPDFReportTitle = 'Report title';  //to translate
 $strPersian = 'Persian';  //to translate
@@ -935,7 +921,6 @@ $strSorting = 'Sorting';  //to translate
 $strSpanish = 'Spanish';  //to translate
 $strSQLCompatibility = 'SQL compatibility mode';  //to translate
 $strSQLExportType = 'Export type';  //to translate
-$strSQLImportOptions = 'SQL options';  //to translate
 $strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
 $strStorageEngines = 'Storage Engines';  //to translate
 $strStorageEngine = 'Storage Engine';  //to translate
@@ -978,16 +963,12 @@ $strQueryResultsOperations = 'Query results operations';  //to translate
 $strAddClause = 'Add %s';  //to translate
 $strUploadsNotAllowed = 'File uploads are not allowed on this server.';  //to translate
 $strOpenDocumentSpreadsheet = 'Open Document Spreadsheet';  //to translate
-$strOpenDocumentSpreadsheetOptions = 'Open Document Spreadsheet options';  //to translate
 $strExportMustBeFile = 'Selected export type has to be saved in file!';  //to translate
-$strXMLOptions = 'XML options';  //to translate
-$strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
 $strCreateUserDatabase = 'Database for user';  //to translate
 $strCreateUserDatabaseNone = 'None';  //to translate
 $strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
 $strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
 $strOpenDocumentText = 'Open Document Text';  //to translate
-$strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
 $strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
 $strCanNotLoadExportPlugins = 'Could not load export plugins, please check your installation!';  //to translate
 $strErrorRenamingTable = 'Error renaming table %1$s to %2$s';  //to translate
@@ -1003,7 +984,6 @@ $strLanguage = 'Language';  //to translate
 $strPmaWiki = 'phpMyAdmin wiki';  //to translate
 $strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
 $strDocSQL = 'DocSQL';  //to translate
-$strDocSQLOptions = 'DocSQL options';  //to translate
 $strTableName = 'Table name';  //to translate
 $strTableIsEmpty = 'Table seems to be empty!';  //to translate
 $strDbIsEmpty = 'Database seems to be empty!';  //to translate
@@ -1048,5 +1028,26 @@ $strErrorRelationExists = 'Error: relation already exists.';  //to translate
 $strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
 $strSnapToGrid = 'Snap to grid';  //to translate
 $strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
+$strUploadErrorIniSize = 'The uploaded file exceeds the upload_max_filesize directive in php.ini.';  //to translate
+$strUploadErrorFormSize = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';  //to translate
+$strUploadErrorPartial = 'The uploaded file was only partially uploaded.';  //to translate
+$strUploadErrorNoTempDir = 'Missing a temporary folder.';  //to translate
+$strUploadErrorCantWrite = 'Failed to write file to disk.';  //to translate
+$strUploadErrorExtension = 'File upload stopped by extension.';  //to translate
+$strUploadErrorUnknown = 'Unknown error in file upload.';  //to translate
 $strSessionStartupErrorGeneral = 'Cannot start session without errors, please check errors given in your PHP and/or webserver log file and configure your PHP installation properly.';  //to translate
+$strFieldInsertFromFileTempDirNotExists = 'Error moving the uploaded file, see FAQ 1.11';  //to translate
+$strViewName = 'VIEW name';  //to translate
+$strOptions = 'Options';  //to translate
+$strFiles = 'Files';  //to translate
+$strIndexesSeemEqual = 'The following indexes appear to be equal and one of them should be removed:';  //to translate
+$strMysqlLibDiffersServerVersion = 'Your PHP MySQL library version %s differs from your MySQL server version %s. This may cause unpredictable behavior.';  //to translate
+$strRoutines = 'Routines';  //to translate
+$strRoutineReturnType = 'Return type';  //to translate
+$strControluserFailed = 'Connection for controluser as defined in your configuration failed.';  //to translate
+$strHexForBLOB = 'Use hexadecimal for BLOB';  //to translate
+$strRestartInsertion = 'Restart insertion with %s rows';  //to translate
+$strTriggers = 'Triggers';  //to translate
+$strEvent = 'Event';  //to translate
+$strProfiling = 'Profiling';  //to translate
 ?>
