@@ -1,11 +1,11 @@
 <?php
-/* $Id: turkish-utf-8.inc.php 10439 2007-06-15 17:13:29Z lem9 $ */
+/* $Id: turkish-utf-8.inc.php 10468 2007-06-27 21:01:13Z lem9 $ */
 
 // phpMyAdmin Türkçe 01.09.2006 itibariyle önceki çeviriye göre çok daha 
 // iyi bir çeviriyle yeniden yapılmıştır. 
 // Birim ayarları Türkçe standartlarına göre tam ve doğru olarak ayarlanmıştır.
 // Çeviren Burak Yavuz (BouRock@live.com)
-// Çeviri sürümü phpMyAdmin 2.9.0.0 ve üzeri sürümlere uygundur.
+// Çeviri sürümü phpMyAdmin 2.10.1.0
 
 $charset = 'utf-8';
 $allow_recoding = TRUE;
@@ -29,8 +29,8 @@ $datefmt = '%d %B %Y saat %H:%M:%S';
 $timespanfmt = '%s gün, %s saat, %s dakika ve %s saniye';
 
 $strAbortedClients = 'İptal edilen';
-$strAccessDeniedCreateConfig = 'Muhtemelen bunun sebebi yapılandırma dosyasını oluşturmadınız. Bir tane oluşturmak için %1$ssetup script%2$s kullanmak isteyebilirsiniz.';
 $strAccessDenied = 'Erişim engellendi';
+$strAccessDeniedCreateConfig = 'Muhtemelen bunun sebebi yapılandırma dosyasını oluşturmadığınız içindir. Bir tane oluşturmak için %1$skurulum programcığı%2$s kullanmak isteyebilirsiniz.';
 $strAccessDeniedExplanation = 'phpMyAdmin MySQL sunucusuna bağlanmayı denedi ama sunucu bağlantıyı reddetti. config.inc içindeki anamakine (host) adresini, kullanıcı adını ve parolayı kontrol edin ve MySQL sunucusunun yöneticisi tarafından verilen bilgiyle uyuştuğundan emin olun.';
 $strAction = 'Eylem';
 $strAddAutoIncrement = 'AUTO_INCREMENT değeri ekle';
@@ -39,7 +39,7 @@ $strAddConstraints = 'Kısıtlamaları ekle';
 $strAddDeleteColumn = 'Alan Sütunları Ekle/Sil';
 $strAddDeleteRow = 'Kriter Satırı Ekle/Sil';
 $strAddFields = '%s alan ekle';
-$strAddHeaderComment = 'Başlık içine özel yorum ekle (\\n satırı böler)';
+$strAddHeaderComment = 'Başlık içine özel yorum ekle (\\n satırları böler)';
 $strAddIntoComments = 'Yorumların içine ekle';
 $strAddNewField = 'Yeni alan ekle';
 $strAddPrivilegesOnDb = 'Aşağıdaki veritabanına yetkileri ekle';
@@ -120,7 +120,7 @@ $strCanNotLoadImportPlugins = 'İçeri aktarma eklentileri yüklenemedi, lütfen
 $strCannotLogin = 'MySQL sunucusuna oturum açılamıyor';
 $strCantLoad = '[a@http://php.net/%1$s@Documentation][em]%1$s[/em][/a] uzantısı yüklenemiyor. Lütfen PHP yapılandırmanızı kontrol edin.';
 $strCantLoadRecodeIconv = 'Karakter grubu dönüşümü için gerekli olan iconv veya recode uzantıları yüklenemedi. Ya PHP\'yi bu uzantıları etkinleştirmek için yapılandırın ya da phpMyAdmin içinde karakter grubu dönüşümünü etkisizleştirin...';
-$strCantRenameIdxToPrimary = 'İndeks\'i PRIMARY olarak yeniden adlandırımazsınız!';
+$strCantRenameIdxToPrimary = 'İndeks\'i PRIMARY olarak yeniden adlandıramazsınız!';
 $strCantUseRecodeIconv = 'Gerekli uzantılar yüklenmiş görünmesine rağmen, ne iconv, ne libinconv, ne de recode_string işlevi kullanılamadı. PHP yapılandırmanızı kontrol edin.';
 $strCardinality = 'Önemlilik';
 $strCaseInsensitive = 'büyük küçük harfe duyarsız';
@@ -163,6 +163,7 @@ $strConnectionError = 'Bağlanamıyor: geçersiz ayarlar.';
 $strConnections = 'Bağlantılar';
 $strConstraintsForDumped = 'Dökümü yapılmış tablolar için kısıtlamalar';
 $strConstraintsForTable = 'Tablo kısıtlamaları';
+$strControluserFailed = 'Yapılandırmanız içinde tanımlanmış denetim kullanıcıları için bağlantı başarısız.';
 $strCookiesRequired = 'Bu kısmı geçmek için tanımlama bilgileri (Cookies) açık olmalı.';
 $strCopyDatabaseOK = '%s veritabanı %s\'e kopyalandı.';
 $strCopy = 'Kopyala';
@@ -188,8 +189,6 @@ $strCreationDates = 'Oluşturma/Güncelleme/Kontrol tarihleri';
 $strCriteria = 'Kriter';
 $strCroatian = 'Hırvatça';
 $strCSV = 'CSV';
-$strCSVImportOptions = 'CSV seçenekleri';
-$strCSVOptions = 'CSV seçenekleri';
 $strCyrillic = 'Kiril';
 $strCzech = 'Çekçe';
 $strCzechSlovak = 'Çekçe-Slovakça';
@@ -233,6 +232,7 @@ $strDelOld = 'Şu anki sayfa, daha fazla bulunması gereksiz tablolara verilmiş
 $strDescending = 'Büyükten Küçüğe';
 $strDescription = 'Açıklama';
 $strDesigner = 'Tasarımcı';
+$strDesignerHelpDisplayField = 'Görüntü alanı pembe ile gösterilir. Alanı, görüntü alanı olarak ayarlamak/ayarı kaldırmak için "Görüntülemek için alan seç" simgesine tıklayın, sonrada uygun alan adı üzerine tıklayın.';
 $strDictionary = 'sözlük';
 $strDirectLinks = 'Doğrudan bağlantılar';
 $strDirtyPages = 'Bozuk sayfalar';
@@ -243,9 +243,8 @@ $strDisplayOrder = 'Görünüm düzeni:';
 $strDisplayPDF = 'PDF şemasını göster';
 $strDoAQuery = '"Örnek sorgu" yap. (joker: "%")';
 $strDocSQL = 'DocSQL';
-$strDocSQLOptions = 'DocSQL seçenekleri';
 $strDocu = 'Belgeler';
-$strDoYouReally = 'Aşağıdaki komutu uygulamak istediğinizden emin misiniz? ';
+$strDoYouReally = 'Aşağıdaki komutu uygulamak istediğinize emin misiniz? ';
 $strDropDatabaseStrongWarning = 'Bütün bir veritabanını YOK ETMEK üzeresiniz!';
 $strDrop = 'Kaldır';
 $strDropUsersDb = 'Kullanıcılarla aynı isimlerde olan veritabanlarını kaldır.';
@@ -280,8 +279,8 @@ $strErrorSaveTable = 'Tasarımcı düzenlemelerini kaydetme hatası.';
 $strEscapeWildcards = '_ ve % jokerleri harfi harfine kullanılmak için \ ile doldurun.';
 $strEsperanto = 'Esperanto';
 $strEstonian = 'Estçe';
+$strEvent = 'Olay';
 $strExcelEdition = 'Excel yapısı';
-$strExcelOptions = 'Excel seçenekleri';
 $strExecuteBookmarked = 'İşaretlenmiş sorguyu çalıştır';
 $strExplain = 'SQL\'i açıkla';
 $strExport = 'Dışarı Aktar';
@@ -293,10 +292,10 @@ $strExtra = 'Ekstra';
 $strFailedAttempts = 'Başarısız deneme';
 $strField = 'Alan';
 $strFieldHasBeenDropped = '%s alanı kaldırıldı';
-$strFields = 'Alanlar';
-$strFieldsEmpty = ' Alan sayısı boş! ';
+$strFieldInsertFromFileTempDirNotExists = 'Gönderilen dosyayı taşıma hatası, SSS 1.11\'e bakın';
 $strFieldsEnclosedBy = 'Alanları kapsayan:';
 $strFieldsEscapedBy = 'Alanları dolduran:';
+$strFields = 'Alanlar';
 $strFieldsTerminatedBy = 'Alanları sonlandıran:';
 $strFileAlreadyExists = '%s dosyası zaten sunucuda var, dosya adını değiştirin veya üzerine yazma seçeneğini işaretleyin.';
 $strFileCouldNotBeRead = 'Dosya okunamadı';
@@ -306,13 +305,14 @@ $strFileNameTemplateDescriptionServer = 'sunucu adı';
 $strFileNameTemplateDescriptionTable = 'tablo adı';
 $strFileNameTemplate = 'Dosya adı şablonu';
 $strFileNameTemplateRemember = 'şablonu hatırla';
+$strFiles = 'Dosyalar';
 $strFileToImport = 'İçeri aktarmak için dosya';
 $strFixed = 'Sabit';
 $strFlushPrivilegesNote = 'Not: phpMyAdmin kullanıcıların yetkilerini doğrudan MySQL\'in yetki tablolarından alır. Bu tabloların içerikleri, eğer elle değiştirildiyse sunucunun kullandığı yetkilerden farklı olabilir. Bu durumda devam etmeden önce %syetkileri yeniden yüklemeniz%s gerekir.';
 $strFlushQueryCache = 'Sorgu önbelleğini temizle';
 $strFlushTables = 'Tüm tabloları temizle (kapat)';
 $strFlushTable = 'Tabloyu temizle ("FLUSH")';
-$strFontSize = 'Tazı Tipi boyutu';
+$strFontSize = 'Yazı Tipi boyutu';
 $strForeignKeyError = 'Dış anahtar oluşturma hatası (veri türlerini kontrol edin)';
 $strFormat = 'Biçim';
 $strFormEmpty = 'Formda eksik değer!';
@@ -342,7 +342,7 @@ $strHasBeenCreated = 'oluşturuldu.';
 $strHaveToShow = 'Görüntülemek için en az bir sütun seçmelisiniz';
 $strHebrew = 'İbranice';
 $strHelp = 'Yardım';
-$strHexForBinary = 'Binari alanları için onaltılık sayı sistemini kullan';
+$strHexForBLOB = 'BLOB için onaltılık sistem kullan';
 $strHide         = 'Gizle';
 $strHideShowAll = 'Tümünü Gizle/Göster';
 $strHideShowNoRelation = 'İlişkisi olmayan Tabloları Gizle/Göster';
@@ -351,9 +351,7 @@ $strHomepageOfficial = 'Resmî phpMyAdmin Anasayfası';
 $strHost = 'Anamakine';
 $strHostEmpty = 'Anamakine adı boş!';
 $strHTMLExcel = 'Microsoft Excel 2000';
-$strHTMLExcelOptions = 'Microsoft Excel 2000 dışarı aktarma seçenekleri';
 $strHTMLWord = 'Microsoft Word 2000';
-$strHTMLWordOptions = 'Microsoft Word 2000 dışarı aktarma seçenekleri';
 $strHungarian = 'Macarca';
 
 $strIcelandic = 'İzlandaca';
@@ -369,13 +367,11 @@ $strImportFormat = 'İçeri aktarılmış dosyanın biçimi';
 $strImportSuccessfullyFinished = 'İçeri aktarma başarılı olarak bitti, %d sorgu çalıştırıldı.';
 $strImport = 'İçeri Aktar';
 $strIndexes = 'İndeksler';
+$strIndexesSeemEqual = 'Aşağıdaki indeksler eşit olarak görünüyor ve bunlardan biri kaldırılmalıdır:';
 $strIndexHasBeenDropped = '%s indeksi kaldırıldı';
 $strIndexName = 'İndeks ismi:';
 $strIndexType = 'İndeks türü :';
-$strIndexWarningMultiple = 'Birden fazla %s anahtarı `%s` sütunu için oluşturuldu.';
-$strIndexWarningPrimary = 'PRIMARY ve INDEX anahtarlarının her ikisi de `%s` sütunu için ayarlanmamalıdır.';
 $strIndexWarningTable = '`%s` tablosunun indeksleri ile ilgili sorunlar';
-$strIndexWarningUnique = 'UNIQUE ve INDEX anahtarlarının her ikisi de `%s` sütunu için ayarlanmamalıdır.';
 $strIndex = 'İndeks';
 $strInnoDBAutoextendIncrement = 'Artış miktarını otomatik genişlet';
 $strInnoDBAutoextendIncrementDesc = 'Tablo dolduğunda otomatik genişleyen tablo alanının genişlemesi için artış miktarı boyutu.';
@@ -435,10 +431,8 @@ $strLatexContinued = '(devam eden)';
 $strLatexIncludeCaption = 'Tablo başlığını dahil et';
 $strLatexLabel = 'Etiket anahtarı';
 $strLaTeX = 'LaTeX';
-$strLaTeXOptions = 'LaTeX seçenekleri';
 $strLatexStructure = '__TABLE__ tablosunun yapısı';
 $strLatvian = 'Litvanyaca';
-$strLDIImportOptions = 'VERİ YÜKLE kullanarak CSV içeri aktarımı için seçenekler';
 $strLDILocal = 'YEREL anahtar kelime kullan';
 $strLDI = 'VERİ YÜKLE kullanarak CSV';
 $strLengthSet = 'Uzunluk/Değerler';
@@ -496,6 +490,7 @@ $strMyISAMSortBufferSizeDesc = 'Bir REPAIR TABLE komutu sırasında MyISAM indek
 $strMySQLCharset = 'MySQL karakter grubu';
 $strMysqlClientVersion = 'MySQL istemci sürümü';
 $strMySQLConnectionCollation = 'MySQL bağlantı karşılaştırması';
+$strMysqlLibDiffersServerVersion = 'PHP MySQL kütüphanenizin %s sürümü MySQL sunucunuzun %s sürümünden farklı. Bu tarafsız davranışa sebep olabilir.';
 $strMySQLSaid = 'MySQL çıktısı: ';
 $strMySQLShowProcess = 'İşlemleri göster';
 $strMySQLShowStatus = 'MySQL çalışma süresi bilgisini göster';
@@ -542,13 +537,12 @@ $strNumTables = 'Tablolar';
 
 $strOK = 'TAMAM';
 $strOpenDocumentSpreadsheet = 'Açık Belge Hesap Çizelgesi';
-$strOpenDocumentSpreadsheetOptions = 'Açık Belge Hesap Çizelgesi seçenekleri';
 $strOpenDocumentText = 'Açık Belge Metini';
-$strOpenDocumentTextOptions = 'Açık Belge Metini seçenekleri';
 $strOpenNewWindow = 'Yeni phpMyAdmin penceresi aç';
 $strOperations = 'İşlemler';
 $strOperator = 'İşletici';
 $strOptimizeTable = 'Tabloyu uyarla';
+$strOptions = 'Seçenekler';
 $strOr = 'Veya';
 $strOverhead = 'Ek Yük';
 $strOverwriteExisting = 'Mevcut dosya(ların)nın üzerine yaz';
@@ -566,7 +560,6 @@ $strPassword = 'Parola';
 $strPdfDbSchema = ' "%s" veritabanının şeması - Sayfa %s';
 $strPdfInvalidTblName = ' "%s" tablosu yok!';
 $strPdfNoTables = 'Tablolar yok';
-$strPDFOptions = 'PDF seçenekleri';
 $strPDF = 'PDF';
 $strPDFReportExplanation = '(Tek tablonun verisini içeren bir rapor üretir)';
 $strPDFReportTitle = 'Rapor başlığı';
@@ -675,12 +668,15 @@ $strReplaceTable = 'Tablo verisini dosya ile değiştir';
 $strReplication = 'Çoğaltma';
 $strReset = 'Sıfırla';
 $strResourceLimits = 'Kaynak sınırları';
+$strRestartInsertion = '%s satırlı eklemeyi yeniden başlat';
 $strReType = 'Yeniden gir';
 $strRevokeAndDeleteDescr = 'Kullanıcılar, yetkiler yeniden yüklenene kadar hala USAGE yetkisine sahip olacaklar.';
 $strRevokeAndDelete = 'Kullanıcılardan tüm aktif yetkileri geri al ve sonra da sil.';
 $strRevoke = 'Geri al';
 $strRevokeMessage = '%s için yetkileri geri aldınız';
 $strRomanian = 'Romence';
+$strRoutines = 'Yordamlar';
+$strRoutineReturnType = 'Dönüş türü';
 $strRowLength = 'Satır uzunluğu';
 $strRowsFrom = 'satır, başlayacağı kayıt numarası:';
 $strRowSize = ' Satır boyutu ';
@@ -732,6 +728,7 @@ $strServerTabVariables = 'Değişkenler';
 $strServerTrafficNotes = '<b>Sunucu trafiği</b>: Bu tablolar sunucunun başlatıldığı andan itibaren MySQL sunucusunun ağ trafiği istatistiklerini gösterir.';
 $strServerVars = 'Sunucu değişkenleri ve ayarları';
 $strServerVersion = 'Sunucu sürümü';
+$strSessionStartupErrorGeneral = 'Oturum hatasız olarak başlatılamıyor, lütfen PHP ve/veya web sunucusu günlüğü dosyanızda verilen hataları kontrol edin ve PHP kurulumunuzu düzgün olarak yapılandırın.';
 $strSessionValue = 'Oturum değeri';
 $strSetEnumVal = 'Eğer alan türü "enum" veya "set" ise lütfen değerleri bu biçimi kullanarak girin: \'a\',\'b\',\'c\'...<br />Eğer bu değerler arasına hep ters eğik çizgi ("\") veya tek tırnak ("\'") koymanız gerekirse, önlerine ters eğik çizgi koyun (örneğin \'\\\\xyz\' veya \'a\\\'b\').';
 $strShowAll = 'Tümünü göster';
@@ -876,8 +873,6 @@ $strSpanish = 'İspanyolca';
 $strSplitWordsWithSpace = 'Kelimeler boşlukla ayrılır (" ").';
 $strSQLCompatibility = 'SQL uyumluluk kipi';
 $strSQLExportType = 'Dışarı aktarma türü';
-$strSQLImportOptions = 'SQL seçenekleri';
-$strSQLOptions = 'SQL seçenekleri';
 $strSQLParserBugMessage = 'SQL ayrıştırıcısında bir hata bulabilme ihtimaliniz var. Lütfen sorgunuzu yakından dikkatli bir şekilde gözden geçirin ve tırnakların doğru ve uyumsuz olmadığını kontrol edin. Diğer muhtemel hata nedenleri tırnaklı metin alanının dışında binari ile dosya gönderiyor olmanız olabilir. Aynı zamanda sorgunuzu MySQL komut satırı arabiriminde deneyebilirsiniz. Eğer hata varsa, aşağıdaki MySQL sunucu hata çıktısı, sorunu teşhis etmenizde ayrıca size yardımcı olabilir. Eğer hala sorunlarınız varsa ya da komut satırı arabirimi başarılı olduğunda ayrıştırıcı başarısızsa, lütfen sorunlara neden olan SQL sorgu girişinizi tek bir sorguya indirgeyin ve aşağıdaki CUT bölümü içindeki veri yığını ile birlikte hata raporunu gönderin:';
 $strSQLParserUserError = 'SQL sorgunuzda bir hata olduğu görünüyor. Eğer varsa, aşağıdaki MySQL sunucu hata çıktısı, sorunu teşhis etmenizde ayrıca size yardımcı olabilir.';
 $strSQLQuery = 'SQL sorgusu';
@@ -899,7 +894,6 @@ $strStrucCSV = 'CSV';
 $strStrucData = 'Yapı ve Veri';
 $strStrucExcelCSV = 'MS Excel için CSV';
 $strStrucNativeExcel = 'Bağımsız MS Excel biçimi';
-$strStrucNativeExcelOptions = 'Bağımsız Excel dışarı aktarma seçenekleri';
 $strStrucOnly = 'Sadece yapı';
 $strStructPropose = 'Tablo yapısı öner';
 $strStructureForView = 'Görünüm yapısı';
@@ -965,6 +959,7 @@ $strTransformation_text_plain__imagelink = 'Bir resim ve bir bağlantı görünt
 $strTransformation_text_plain__link = 'Bir bağlantı görüntüler; alan dosya adını içerir. İlk seçenek "http://www.adresim.com/" gibi bir URL ön ekidir. İkinci seçenek bağlantı için başlıktır.';
 $strTransformation_text_plain__sql = 'Sözdizimi vurgulamalı SQL sorgusu gibi metni biçimlendirir.';
 $strTransformation_text_plain__substr = 'Karakter dizisinin bir kısmını görüntüler. İlk seçenek dizginin başlangıcından atlamak için karakter sayısıdır (Varsayılan 0). İkinci seçenek döndürülecek karakter sayısıdır (Varsayılan: dizginin sonuna kadar). Üçüncü seçenek kısaltma meydana geldiğinde eklemek ve/veya başa eklemek için dizgidir (Varsayılan: "...").';
+$strTriggers = 'Tetiklemeler';
 $strTruncateQueries = 'Gösterilen Sorguları Kısalt';
 $strTurkish = 'Türkçe';
 $strType = 'Türü';
@@ -981,6 +976,13 @@ $strUpdateProfileMessage = 'Profil güncellendi.';
 $strUpdateQuery = 'Sorguyu Güncelle';
 $strUpdComTab = 'Sütun_Yorumları tablonuzun nasıl güncelleneceğini öğrenmek için lütfen belgelere bakın.';
 $strUpgrade = '%s %s veya sonrasına yükseltmelisiniz.';
+$strUploadErrorCantWrite = 'Dosyayı diske yazma başarısız.';
+$strUploadErrorExtension = 'Dosya gönderme uzantısından dolayı durduruldu.';
+$strUploadErrorFormSize = 'Gönderilen dosya, HTML formu içinde belirlenmiş MAX_FILE_SIZE yönergesini aşıyor.';
+$strUploadErrorIniSize = 'Gönderilen dosya, php.ini içindeki upload_max_filesize yönergesini aşıyor.';
+$strUploadErrorNoTempDir = 'Eksik geçici klasör.';
+$strUploadErrorPartial = 'Gönderilen dosya sadece kısmen gönderildi.';
+$strUploadErrorUnknown = 'Dosya göndermede bilinmeyen hata oldu.';
 $strUploadLimit = 'Muhtemelen çok büyük dosya göndermeyi denediniz. Lütfen bu sınıra çözüm yolu bulmak için %sbelgelere%s başvurun.';
 $strUploadsNotAllowed = 'Bu sunucuda dosya gönderimlerine izin verilmez.';
 $strUsage = 'Kullanım';
@@ -1008,9 +1010,10 @@ $strVersionInformation = 'Sürüm bilgisi';
 $strViewDumpDatabases = 'Veritabanlarının dökümünü (şemasını) göster';
 $strViewDumpDB = 'Veritabanının dökümünü (şemasını) göster';
 $strViewDump = 'Tablonun dökümünü (şemasını) göster';
-$strView = 'Görünüm';
 $strViewHasBeenDropped = '%s görünümü kaldırıldı';
 $strViewMaxExactCount = 'Bu görünüm %s satırdan daha fazla. Lütfen %sbelgelere%s başvurun.';
+$strViewName = 'GÖRÜNÜM adı';
+$strView = 'Görünüm';
 
 $strWebServerUploadDirectoryError = 'Gönderme işi için ayarladığınız dizine ulaşılamıyor';
 $strWebServerUploadDirectory = 'web sunucusu gönderme dizini';
@@ -1022,7 +1025,6 @@ $strWithChecked = 'Seçilileri:';
 $strWriteRequests = 'Yazma istekleri';
 $strWrongUser = 'Yanlış kullanıcı adı/parola. Erişim engellendi.';
 
-$strXMLOptions = 'XML seçenekleri';
 $strXML = 'XML';
 
 $strYes = 'Evet';
@@ -1030,6 +1032,5 @@ $strYes = 'Evet';
 $strZeroRemovesTheLimit = 'Not: Bu seçeneklerin 0 (sıfır)\'a ayarlanması sınırı kaldırır.';
 $strZip = '"zip olarak"';
 
-$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
-$strSessionStartupErrorGeneral = 'Cannot start session without errors, please check errors given in your PHP and/or webserver log file and configure your PHP installation properly.';  //to translate
+$strProfiling = 'Profiling';  //to translate
 ?>
